# mkpi [![Version][version-badge]][version-link]![MIT License][license-badge]

make python project setuptools template

是一个用来自动生成python project setup模板的工具 

### 示例

### 使用方式

```
Usage: mkpi [-h] [--name PROJECT_NAME]

optional arguments:
    -h --help   show this help message
    --name      name of the project you want to create
```

### 安装

```
$ pip install mkpi
```

### License

[MIT](https://github.com/wanix1988/python-setup-boilerplate/blob/master/LICENSE)
[version-badge]: https://img.shields.io/badge/version-0.1-brightgreen.svg
[version-link]:    https://pypi.org/project/mkpi
[license-badge]:   https://img.shields.io/github/license/mashape/apistatus.svg